# jupyter-math

[![Build Status](https://travis-ci.org/Madoshakalaka/jupyter-math.svg)](https://travis-ci.org/Madoshakalaka/jupyter-math)
[![codecov](https://codecov.io/gh/Madoshakalaka/jupyter-math/branch/master/graph/badge.svg)](https://codecov.io/gh/Madoshakalaka/jupyter-math)
[![PyPI version](https://badge.fury.io/py/jupyter-math.svg)](https://badge.fury.io/py/jupyter-math)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/jupyter-math.svg)](https://pypi.python.org/pypi/jupyter-math/)


## Installation

`pip install jupyter-math`

## What Does It Do

evaluate and display math on jupyter notebook with latex

![what-does-it-do](https://raw.githubusercontent.com/Madoshakalaka/jupyter-math/master/readme_assets/glorious.png)

## How to Use

Don't Use it.

I just came this overnight.

If you really want to use it.

Go to [this notebook file](./tests/interactive_test.ipynb) to see some use cases.

<!--

add some help here 

```python

```

-->

